@@ -39,6 +39,9 @@ func (b *NodeTerminationHandlerOptionsBuilder) BuildOptions(o interface{}) error
 		clusterSpec.CloudProvider.AWS.NodeTerminationHandler = &kops.NodeTerminationHandlerSpec{}
 	}
 	nth := clusterSpec.CloudProvider.AWS.NodeTerminationHandler
+	if nth.DeleteSQSMsgIfNodeNotFound == nil {
+		nth.DeleteSQSMsgIfNodeNotFound = fi.PtrTo(false)
+	}
 	if nth.Enabled == nil {
 		nth.Enabled = fi.PtrTo(true)
 	}
@@ -67,6 +70,14 @@ func (b *NodeTerminationHandlerOptionsBuilder) BuildOptions(o interface{}) error
 		nth.ManagedASGTag = fi.PtrTo("aws-node-termination-handler/managed")
 	}
 
+	if nth.PodTerminationGracePeriod == nil {
+		nth.PodTerminationGracePeriod = fi.PtrTo(int32(-1))
+	}
+
+	if nth.TaintNode == nil {
+		nth.TaintNode = fi.PtrTo(false)
+	}
+
 	if nth.CPURequest == nil {
 		defaultCPURequest := resource.MustParse("50m")
 		nth.CPURequest = &defaultCPURequest
@@ -78,7 +89,7 @@ func (b *NodeTerminationHandlerOptionsBuilder) BuildOptions(o interface{}) error
 	}
 
 	if nth.Version == nil {
-		nth.Version = fi.PtrTo("v1.18.3")
+		nth.Version = fi.PtrTo("v1.22.0")
 	}
 
 	return nil
