@@ -215,7 +215,7 @@ func findNatGatewayFromRouteTable(ctx context.Context, cloud awsup.AWSCloud, rou
 			var natGatewayIDs []*string
 			natGatewayIDsSeen := map[string]bool{}
 			for _, route := range rt.Routes {
-				if route.NatGatewayId != nil && !natGatewayIDsSeen[*route.NatGatewayId] {
+				if route.NatGatewayId != nil && route.State != ec2types.RouteStateBlackhole && !natGatewayIDsSeen[*route.NatGatewayId] {
 					natGatewayIDs = append(natGatewayIDs, route.NatGatewayId)
 					natGatewayIDsSeen[*route.NatGatewayId] = true
 				}
