@@ -255,6 +255,8 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 				"DISABLE_METRICS":                       "false",
 				"ENABLE_POD_ENI":                        "false",
 				"ENABLE_PREFIX_DELEGATION":              "false",
+				"ENABLE_SUBNET_DISCOVERY":               "true",
+				"NETWORK_POLICY_ENFORCING_MODE":         "standard",
 				"WARM_ENI_TARGET":                       "1",
 				"WARM_PREFIX_TARGET":                    "1",
 				"DISABLE_NETWORK_RESOURCE_PROVISIONING": "false",
@@ -809,6 +811,8 @@ func (tf *TemplateFunctions) ExternalDNSArgv() ([]string, error) {
 	switch cloudProvider {
 	case kops.CloudProviderAWS:
 		argv = append(argv, "--provider=aws")
+	case kops.CloudProviderOpenstack:
+		argv = append(argv, "--provider=designate")
 	case kops.CloudProviderGCE:
 		project := cluster.Spec.CloudProvider.GCE.Project
 		argv = append(argv, "--provider=google")
