@@ -20,10 +20,6 @@ type Target[T SubContext] interface {
 	// Lifecycle methods, called by the driver
 	Finish(taskMap map[string]Task[T]) error
 
-	// ProcessDeletions returns true if we should delete resources
-	// Some providers (e.g. Terraform) actively keep state, and will delete resources automatically
-	ProcessDeletions() bool
-
 	// DefaultCheckExisting returns true if DefaultDeltaRun tasks which aren't HasCheckExisting
 	// should invoke Find() when running against this Target.
 	DefaultCheckExisting() bool
